@@ -3,7 +3,6 @@ package addon_test
 import (
 	"context"
 	"fmt"
-	"time"
 
 	"github.com/aws/aws-sdk-go-v2/aws"
 	awseks "github.com/aws/aws-sdk-go-v2/service/eks"
@@ -30,7 +29,7 @@ var _ = Describe("Get", func() {
 		manager, err = addon.New(&api.ClusterConfig{Metadata: &api.ClusterMeta{
 			Version: "1.18",
 			Name:    "my-cluster",
-		}}, mockProvider.EKS(), nil, false, nil, nil, 5*time.Minute)
+		}}, mockProvider.EKS(), nil, false, nil, nil)
 		Expect(err).NotTo(HaveOccurred())
 	})
 
