@@ -4,7 +4,6 @@ import (
 	"fmt"
 
 	. "github.com/onsi/ginkgo/v2"
-
 	. "github.com/onsi/gomega"
 
 	api "github.com/weaveworks/eksctl/pkg/apis/eksctl.io/v1alpha5"
@@ -16,7 +15,6 @@ var _ = Describe("GPU instance support", func() {
 	type gpuInstanceEntry struct {
 		gpuInstanceType string
 		amiFamily       string
-		customErr       string
 
 		expectUnsupportedErr bool
 	}
@@ -24,9 +22,7 @@ var _ = Describe("GPU instance support", func() {
 	assertValidationError := func(e gpuInstanceEntry, err error) {
 		if e.expectUnsupportedErr {
 			Expect(err).To(HaveOccurred())
-			if e.customErr != "" {
-				Expect(err).To(MatchError(e.customErr))
-			} else if instanceutils.IsNvidiaInstanceType(e.gpuInstanceType) {
+			if instanceutils.IsNvidiaInstanceType(e.gpuInstanceType) {
 				Expect(err).To(MatchError(ContainSubstring(fmt.Sprintf("GPU instance types are not supported for %s", e.amiFamily))))
 			} else {
 				Expect(err).To(MatchError(ContainSubstring(fmt.Sprintf("Inferentia instance types are not supported for %s", e.amiFamily))))
@@ -51,12 +47,6 @@ var _ = Describe("GPU instance support", func() {
 			gpuInstanceType: "g5.12xlarge",
 			amiFamily:       api.NodeImageFamilyAmazonLinux2,
 		}),
-		Entry("Bottlerocket", gpuInstanceEntry{
-			amiFamily:            api.NodeImageFamilyBottlerocket,
-			gpuInstanceType:      "g4dn.xlarge",
-			expectUnsupportedErr: true,
-			customErr:            fmt.Sprintf("NVIDIA GPU instance types are not supported for managed nodegroups with AMIFamily %s", api.NodeImageFamilyBottlerocket),
-		}),
 		Entry("Ubuntu2004", gpuInstanceEntry{
 			amiFamily:            api.NodeImageFamilyUbuntu2004,
 			gpuInstanceType:      "g4dn.xlarge",
@@ -95,11 +85,15 @@ var _ = Describe("GPU instance support", func() {
 			amiFamily:       api.NodeImageFamilyBottlerocket,
 			gpuInstanceType: "g4dn.xlarge",
 		}),
-		Entry("Bottlerocket", gpuInstanceEntry{
+		Entry("Bottlerocket infra", gpuInstanceEntry{
 			amiFamily:            api.NodeImageFamilyBottlerocket,
 			gpuInstanceType:      "inf1.xlarge",
 			expectUnsupportedErr: true,
 		}),
+		Entry("Bottlerocket nvidia", gpuInstanceEntry{
+			amiFamily:       api.NodeImageFamilyBottlerocket,
+			gpuInstanceType: "g4dn.xlarge",
+		}),
 		Entry("Ubuntu2004", gpuInstanceEntry{
 			amiFamily:            api.NodeImageFamilyUbuntu2004,
 			gpuInstanceType:      "g4dn.xlarge",
@@ -126,4 +120,15 @@ var _ = Describe("GPU instance support", func() {
 			expectUnsupportedErr: true,
 		}),
 	)
+	Describe("ARM GPU", func() {
+		When("ARM GPU instance is request for unmanaged nodegroups", func() {
+			It("errors", func() {
+				ng := api.NewNodeGroup()
+				ng.InstanceType = "g5g.xlarge"
+				ng.AMIFamily = api.NodeImageFamilyBottlerocket
+				err := api.ValidateNodeGroup(0, ng)
+				Expect(err).To(MatchError(ContainSubstring("ARM GPU instance types are not supported for unmanaged nodegroups with AMIFamily Bottlerocket")))
+			})
+		})
+	})
 })
