@@ -5,6 +5,8 @@ import (
 	"fmt"
 	"io"
 
+	"github.com/aws/amazon-ec2-instance-selector/v2/pkg/selector"
+
 	"github.com/kris-nova/logger"
 	"github.com/pkg/errors"
 	"github.com/spf13/cobra"
@@ -49,7 +51,7 @@ func createNodeGroupCmd(cmd *cmdutils.Cmd) {
 			}()
 		}
 
-		ctx := context.TODO()
+		ctx := context.Background()
 		ctl, err := cmd.NewProviderForExistingCluster(ctx)
 		if err != nil {
 			return errors.Wrap(err, "couldn't create cluster provider from options")
@@ -64,7 +66,7 @@ func createNodeGroupCmd(cmd *cmdutils.Cmd) {
 			return err
 		}
 
-		manager := nodegroup.New(cmd.ClusterConfig, ctl, clientSet)
+		manager := nodegroup.New(cmd.ClusterConfig, ctl, clientSet, selector.New(ctl.AWSProvider.Session()))
 		return manager.Create(ctx, nodegroup.CreateOpts{
 			InstallNeuronDevicePlugin: options.InstallNeuronDevicePlugin,
 			InstallNvidiaDevicePlugin: options.InstallNvidiaDevicePlugin,
